/*
 * $Id: chkreset.c,v 1.4 1992/07/29 07:55:18 proj Exp $
 */
/*
 * X11R5 Input Method Test Program
 * ximtest.c v 1.0   Mon Mar 18 15:05:15 JST 1991
 */

/*
 * Copyright 1991, 1992 by OMRON Corporation
 *
 *      Author: Takashi Inoue    OMRON Corporation
 *                               takashi@ari.ncl.omron.co.jp
 */

#include <stdio.h>
#include "exvalue.h"
#include "func.h"

FLAG	preset(ic, mode)		/* Preedit area RESET */
XIC	ic;
FLAG	mode;
{
    if (mode == ONSP) {
	prerrfunc();
	return (COMP);
    } else {
	cls(prdisp);
	if (strflag == MB) {
	    prstatus("Test of XmbResetIC()...");
	    XmbResetIC(ic);
	} else if (strflag == WC) {
	    prstatus("Test of XwcResetIC()...");
	    XwcResetIC(ic);
	}
	prstatus("done.");
	prprint("Check your own eyes if preedit area on the test window is clear.\n\n");
	prprint("And re-input string.\n\n");
	if (strflag == MB) {
	    fprintf(icfp, "...XmbResetIC returned.\n\n");
	} else if (strflag == WC) {
	    fprintf(icfp, "...XwcResetIC returned.\n\n");
	}
	return (COMP);
    }
}



