/*
 * $Id: sheader.h,v 1.9 1992/12/01 06:11:05 proj Exp $
 */
/*
 * Copyright 1989, 1990, 1991, 1992 by OMRON Corporation
 * Copyright 1991, 1992 by Massachusetts Institute of Technology
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of OMRON and MIT not be used in
 * advertising or publicity pertaining to distribution of the software without
 * specific, written prior permission.  OMRON and MIT make no representations
 * about the suitability of this software for any purpose.  It is provided
 * "as is" without express or implied warranty.
 *
 * Wnn consortium is one of distributors of the official Wnn source code
 * release.  Wnn consortium also makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * OMRON, MIT AND WNN CONSORTIUM DISCLAIM ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL OMRON, MIT OR WNN CONSORTIUM BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
 * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
 * CONTRACT, NEGLIGENCE OR OTHER TORTUOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 *	Author:	Seiji Kuwari	OMRON Corporation
 *				kuwa@omron.co.jp
 *				kuwa%omron.co.jp@uunet.uu.net
 */				
/*
 * Copyright Kyoto University Research Institute for Mathematical Sciences
 *                 1987, 1988, 1989, 1990, 1991, 1992
 * Copyright OMRON Corporation. 1987, 1988, 1989, 1990, 1991, 1992
 * Copyright ASTEC, Inc. 1987, 1988, 1989, 1990, 1991, 1992
 *
 * Permission to use, copy, modify, distribute, and sell this software
 * and its documentation for any purpose is hereby granted without fee,
 * provided that all of the following conditions are satisfied:
 *
 * 1) The above copyright notices appear in all copies
 * 2) Both those copyright notices and this permission notice appear
 *    in supporting documentation
 * 3) The name of "Wnn" isn't changed unless substantial modifications
 *    are made, or
 * 3') Following words followed by the above copyright notices appear
 *    in all supporting documentation of software based on "Wnn":
 *
 *   "This software is based on the original version of Wnn developed by
 *    Kyoto University Research Institute for Mathematical Sciences (KURIMS),
 *    OMRON Corporation and ASTEC Inc."
 *
 * 4) The names KURIMS, OMRON and ASTEC not be used in advertising or
 *    publicity pertaining to distribution of the software without
 *    specific, written prior permission
 *
 * KURIMS, OMRON and ASTEC make no representations about the suitability
 * of this software for any purpose.  It is provided "as is" without
 * express or implied warranty.
 *
 * Wnn consortium is one of distributors of the official Wnn source code
 * release.  Wnn consortium also makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * KURIMS, OMRON, ASTEC AND WNN CONSORTIUM DISCLAIM ALL WARRANTIES WITH
 * REGARD TO THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL KURIMS, OMRON, ASTEC OR
 * WNN CONSORTIUM BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
 * DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR
 * PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTUOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 *
 */
/*	Version 4.0
 */
/**************************
 * header of standard i/o 
 **************************/

#ifndef	_HEADER_H_
#define	_HEADER_H_

extern int rubout_code;
extern int kk_on;
extern int quote_code; 

extern char *ximrc_file;
extern char *cvt_key_file;
extern char *cvt_fun_file;
extern char *cvt_meta_file;
extern int defined_by_option;

extern	WNN_DIC_INFO	*dicinfo;
extern int dic_list_size;

extern char *prgname;

extern char *xim_title;

extern char *display_name;
#ifdef	USING_XJUTIL
extern char *xjutil_name;
#endif	/* USING_XJUTIL */

extern char *def_lang;
extern char *def_locale;
extern char *world_locale;

extern XIMLangDataBase *cur_lang;

extern WnnClientRec	*c_c;
extern XIMClientRec	*cur_p;
extern XIMClientRec	*cur_x;
extern XIMInputRec	*cur_input;
extern XInputManager	*xim;
extern XIMInputList	input_list;
extern WnnClientList	wnnclient_list;
extern XIMClientList	ximclient_list;
extern ReadRkfileList	read_rkfile_list;
extern BoxRec		*box_list;

extern Romkan		*cur_rk;
extern RomkanTable	*cur_rk_table;

extern char read_rk_file[MAX_LANGS][62];

extern struct msg_cat *cd;

extern char		*root_def_servername;
extern char		*root_def_reverse_servername;
extern char		*root_username;
extern Bool		root_henkan_off_def;
extern char		*root_uumkeyname;
extern char		*root_rkfilename;

extern char		*world_lang;
extern char		*arg_string;

extern char *default_message[];

extern wchar		*wc_buf;
extern unsigned char	*ct_buf;
extern unsigned char	*c_buf;
extern int		wc_buf_max;
extern int		ct_buf_max;
extern int		c_buf_max;
#ifndef X_WCHAR
extern wchar_t		*wt_buf;
extern int		wt_buf_max;
#endif /* !X_WCHAR */

extern ConvCode cvt_key_tbl[];
extern int cvt_key_tbl_cnt;

extern XIMLangDataBase *language_db;
extern XIMLcNameRec *lc_name_list;
extern FunctionTable function_db[];
#endif	/* _HEADER_H_ */
