/*
 * $Id: Ximprot.h,v 1.1 1994/08/04 07:01:47 li Exp $
 */
/*****************************************************************
  Copyright 1994 by OMRON Corporation
               All Rights Reserved
 *****************************************************************/
#ifndef _XIMPROT_H
#define _XIMPROT_H

#include <X11/Xproto.h>
#include "XimProto.h"

typedef struct {
    CARD8       major_opcode;
    CARD8       minor_opcode;
    CARD16      length;
    CARD8       *data;
} XimRequestPacket;

#endif /* _XIMPROT_H */
