/*
 * $Id: chkfe.c,v 1.2 1991/10/30 09:31:53 xi18n Exp $
 */
/*
 * X11R5 Input Method Test Program
 * chkfe.c v 1.0   Fri Mar  8 09:13:21 JST 1991
 */

/*
 * Copyright 1991 by OMRON Corporation
 *
 *      Author: Takashi Inoue    OMRON Corporation
 *                               takashi@ari.ncl.omron.co.jp
 */

#include 	"exvalue.h"
#include 	"func.h"

FLAG	fltev(event)
XEvent	*event;
{
    Bool	res;

/*  prstatus("Calling XFilterEvent()..."); */
    res = XFilterEvent(event, event->xany.window);
/*  prstatus("done."); */
    cls(prdisp);
    if (res == False) {
/*	prprint("The result of XFilterEvent() is \"False\".\n");  */
	fprintf(icfp, "The result of XFilterEvent() is \"False\".\n");
	return (NG);
    } else {
/*	prprint("The result of XFilterEvent() is \"True\".\n");  */
	fprintf(icfp, "The result of XFilterEvent() is \"True\".\n");
    	return (OK);
    }
}

