/*
 * $Id: message.c,v 1.2 1991/09/16 21:37:09 ohm Exp $
 */
/*
 * Copyright 1989, 1990, 1991 by OMRON Corporation
 * Copyright 1991 by Massachusetts Institute of Technology
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the names of OMRON and MIT not be used in
 * advertising or publicity pertaining to distribution of the software without
 * specific, written prior permission.  OMRON and MIT make no representations
 * about the suitability of this software for any purpose.  It is provided
 * "as is" without express or implied warranty.
 *
 * Wnn consortium is one of distributors of the official Wnn source code
 * release.  Wnn consortium also makes no representations about the
 * suitability of this software for any purpose.  It is provided "as is"
 * without express or implied warranty.
 *
 * OMRON, MIT AND WNN CONSORTIUM DISCLAIM ALL WARRANTIES WITH REGARD TO
 * THIS SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS, IN NO EVENT SHALL OMRON, MIT OR WNN CONSORTIUM BE LIABLE FOR ANY
 * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER
 * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF
 * CONTRACT, NEGLIGENCE OR OTHER TORTUOUS ACTION, ARISING OUT OF OR IN
 * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 *
 *	Author:	Seiji Kuwari	OMRON Corporation
 *				kuwa@omron.co.jp
 *				kuwa%omron.co.jp@uunet.uu.net
 */				

char *default_message[] = {
/* 0 */		"Save was completed",
/* 1 */		"CANDIDATES(SMALL)",
/* 2 */		"CANDIDATES(LARGE)",
/* 3 */		"You can't get candidates becuase candidates are too many.",
/* 4 */		"Frequency",
/* 5 */		"Evaluation value",
/* 6 */		"Front vector",
/* 7 */		"Evaluation value(LARGE)",
/* 8 */		"Yomi",
/* 9 */		"do you want remove",
/* 10 */	"You can't remove a entry of hard-dictionary.",
/* 11 */	"You can't remove a entry of read-only-dictionary.",
/* 12 */	"{",
/* 13 */	"} will be remove",
/* 14 */	"You can't change because the frequency is read-only.",
/* 15 */	"} will become unuse",
/* 16 */	"  CANCEL  ",
/* 17 */	"JIS code input",
/* 18 */	"Please input JIS code",
/* 19 */	"Execute",
/* 20 */	"Dictionary utility",
/* 21 */	"Can't open default uumkey.",
/* 22 */	"Can't expand.",
/* 23 */	"Duplicate definition at key.",
/* 24 */	"KUTEN input",
/* 25 */	"Please input KUTEN",
/* 26 */	"KU",
/* 27 */	"Connection to jserver is closed.",
/* 28 */	"Can't open a default uumrc.",
/* 29 */	"Connection",
/* 30 */	"Please input hostname",
/* 31 */	"Connection is wrong",
/* 32 */	"Connection failed",
/* 33 */	"Connection was completed",
/* 34 */	"  INSPECT   ",
/* 35 */	"DELE",
/* 36 */	" USE/UNUSE ",
/* 37 */	"NEXT",
/* 38 */	"PREV",
/* 39 */	"  MOUSE   ",
/* 40 */	"   KEY    ",
/* 41 */	"  NEXT  ",
/* 42 */	"PREVIOUS",
/* 43 */	"DIC ADD",
/* 44 */	"DIC LIST",
/* 45 */	"REGISTER",
/* 46 */	"SEARCH",
/* 47 */	"CHANGE PARA",
/* 48 */	"SAVE",
/* 49 */	"DIC INFO",
/* 50 */	"CHANGE FUZ",
/* 51 */	" YES  ",
/* 52 */	"  NO  ",
/* 53 */	" OK ? "
};
